==> zio-aws-globalaccelerator_2.13-5.17.104.13-sources.jar: zio/aws/globalaccelerator/model/AllowCustomRoutingTrafficRequest.scala <==
package zio.aws.globalaccelerator.model
import java.lang.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.globalaccelerator.model.primitives.{
  GenericBoolean,
  PortNumber,
  IpAddress,
  GenericString
}
import scala.jdk.CollectionConverters._
final case class AllowCustomRoutingTrafficRequest(
    endpointGroupArn: GenericString,
    endpointId: GenericString,
    destinationAddresses: Option[Iterable[IpAddress]] = None,
    destinationPorts: Option[Iterable[PortNumber]] = None,
    allowAllTrafficToEndpoint: Option[GenericBoolean] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.globalaccelerator.model.AllowCustomRoutingTrafficRequest = {
    import AllowCustomRoutingTrafficRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.globalaccelerator.model.AllowCustomRoutingTrafficRequest
      .builder()
      .endpointGroupArn(
        GenericString.unwrap(endpointGroupArn): java.lang.String
      )
      .endpointId(GenericString.unwrap(endpointId): java.lang.String)
      .optionallyWith(
        destinationAddresses.map(value =>
          value.map { item =>
            IpAddress.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.destinationAddresses)
      .optionallyWith(
        destinationPorts.map(value =>
          value.map { item =>
            PortNumber.unwrap(item): Integer
          }.asJavaCollection
        )
      )(_.destinationPorts)
      .optionallyWith(
        allowAllTrafficToEndpoint.map(value =>
          GenericBoolean.unwrap(value): java.lang.Boolean
        )
      )(_.allowAllTrafficToEndpoint)
      .build()
  }
  def asReadOnly
      : zio.aws.globalaccelerator.model.AllowCustomRoutingTrafficRequest.ReadOnly =
    zio.aws.globalaccelerator.model.AllowCustomRoutingTrafficRequest
      .wrap(buildAwsValue())
}
object AllowCustomRoutingTrafficRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.globalaccelerator.model.AllowCustomRoutingTrafficRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.globalaccelerator.model.AllowCustomRoutingTrafficRequest =
      zio.aws.globalaccelerator.model.AllowCustomRoutingTrafficRequest(
        endpointGroupArn,
        endpointId,
        destinationAddresses.map(value => value),
        destinationPorts.map(value => value),
        allowAllTrafficToEndpoint.map(value => value)
      )
    def endpointGroupArn: GenericString
    def endpointId: GenericString
    def destinationAddresses: Option[List[IpAddress]]
    def destinationPorts: Option[List[PortNumber]]
    def allowAllTrafficToEndpoint: Option[GenericBoolean]
    def getEndpointGroupArn: ZIO[Any, Nothing, GenericString] =
      ZIO.succeed(endpointGroupArn)
    def getEndpointId: ZIO[Any, Nothing, GenericString] =
      ZIO.succeed(endpointId)
    def getDestinationAddresses: ZIO[Any, AwsError, List[IpAddress]] =
      AwsError.unwrapOptionField("destinationAddresses", destinationAddresses)
    def getDestinationPorts: ZIO[Any, AwsError, List[PortNumber]] =
      AwsError.unwrapOptionField("destinationPorts", destinationPorts)
    def getAllowAllTrafficToEndpoint: ZIO[Any, AwsError, GenericBoolean] =
      AwsError.unwrapOptionField(
        "allowAllTrafficToEndpoint",
        allowAllTrafficToEndpoint
      )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.globalaccelerator.model.AllowCustomRoutingTrafficRequest
  ) extends zio.aws.globalaccelerator.model.AllowCustomRoutingTrafficRequest.ReadOnly {
    override val endpointGroupArn: GenericString =
      zio.aws.globalaccelerator.model.primitives
        .GenericString(impl.endpointGroupArn())
    override val endpointId: GenericString =
      zio.aws.globalaccelerator.model.primitives
        .GenericString(impl.endpointId())
    override val destinationAddresses: Option[List[IpAddress]] = scala
      .Option(impl.destinationAddresses())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.globalaccelerator.model.primitives.IpAddress(item)
        }.toList
      )
    override val destinationPorts: Option[List[PortNumber]] = scala
      .Option(impl.destinationPorts())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.globalaccelerator.model.primitives.PortNumber(item)
        }.toList
      )
    override val allowAllTrafficToEndpoint: Option[GenericBoolean] = scala
      .Option(impl.allowAllTrafficToEndpoint())
      .map(value =>
        zio.aws.globalaccelerator.model.primitives.GenericBoolean(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.globalaccelerator.model.AllowCustomRoutingTrafficRequest
  ): zio.aws.globalaccelerator.model.AllowCustomRoutingTrafficRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-globalaccelerator_2.13-5.17.158.1-sources.jar: zio/aws/globalaccelerator/model/AllowCustomRoutingTrafficRequest.scala <==
package zio.aws.globalaccelerator.model
import java.lang.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.globalaccelerator.model.primitives.{
  GenericBoolean,
  PortNumber,
  IpAddress,
  GenericString
}
import scala.jdk.CollectionConverters._
final case class AllowCustomRoutingTrafficRequest(
    endpointGroupArn: GenericString,
    endpointId: GenericString,
    destinationAddresses: Option[Iterable[IpAddress]] = None,
    destinationPorts: Option[Iterable[PortNumber]] = None,
    allowAllTrafficToEndpoint: Option[GenericBoolean] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.globalaccelerator.model.AllowCustomRoutingTrafficRequest = {
    import AllowCustomRoutingTrafficRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.globalaccelerator.model.AllowCustomRoutingTrafficRequest
      .builder()
      .endpointGroupArn(endpointGroupArn: java.lang.String)
      .endpointId(endpointId: java.lang.String)
      .optionallyWith(
        destinationAddresses.map(value =>
          value.map { item =>
            IpAddress.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.destinationAddresses)
      .optionallyWith(
        destinationPorts.map(value =>
          value.map { item =>
            PortNumber.unwrap(item): Integer
          }.asJavaCollection
        )
      )(_.destinationPorts)
      .optionallyWith(
        allowAllTrafficToEndpoint.map(value => value: java.lang.Boolean)
      )(_.allowAllTrafficToEndpoint)
      .build()
  }
  def asReadOnly
      : zio.aws.globalaccelerator.model.AllowCustomRoutingTrafficRequest.ReadOnly =
    zio.aws.globalaccelerator.model.AllowCustomRoutingTrafficRequest
      .wrap(buildAwsValue())
}
object AllowCustomRoutingTrafficRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.globalaccelerator.model.AllowCustomRoutingTrafficRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.globalaccelerator.model.AllowCustomRoutingTrafficRequest =
      zio.aws.globalaccelerator.model.AllowCustomRoutingTrafficRequest(
        endpointGroupArn,
        endpointId,
        destinationAddresses.map(value => value),
        destinationPorts.map(value => value),
        allowAllTrafficToEndpoint.map(value => value)
      )
    def endpointGroupArn: GenericString
    def endpointId: GenericString
    def destinationAddresses: Option[List[IpAddress]]
    def destinationPorts: Option[List[PortNumber]]
    def allowAllTrafficToEndpoint: Option[GenericBoolean]
    def getEndpointGroupArn: ZIO[Any, Nothing, GenericString] =
      ZIO.succeed(endpointGroupArn)
    def getEndpointId: ZIO[Any, Nothing, GenericString] =
      ZIO.succeed(endpointId)
    def getDestinationAddresses: ZIO[Any, AwsError, List[IpAddress]] =
      AwsError.unwrapOptionField("destinationAddresses", destinationAddresses)
    def getDestinationPorts: ZIO[Any, AwsError, List[PortNumber]] =
      AwsError.unwrapOptionField("destinationPorts", destinationPorts)
    def getAllowAllTrafficToEndpoint: ZIO[Any, AwsError, GenericBoolean] =
      AwsError.unwrapOptionField(
        "allowAllTrafficToEndpoint",
        allowAllTrafficToEndpoint
      )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.globalaccelerator.model.AllowCustomRoutingTrafficRequest
  ) extends zio.aws.globalaccelerator.model.AllowCustomRoutingTrafficRequest.ReadOnly {
    override val endpointGroupArn: GenericString =
      impl.endpointGroupArn(): GenericString
    override val endpointId: GenericString = impl.endpointId(): GenericString
    override val destinationAddresses: Option[List[IpAddress]] = scala
      .Option(impl.destinationAddresses())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.globalaccelerator.model.primitives.IpAddress(item)
        }.toList
      )
    override val destinationPorts: Option[List[PortNumber]] = scala
      .Option(impl.destinationPorts())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.globalaccelerator.model.primitives.PortNumber(item)
        }.toList
      )
    override val allowAllTrafficToEndpoint: Option[GenericBoolean] = scala
      .Option(impl.allowAllTrafficToEndpoint())
      .map(value => value: GenericBoolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.globalaccelerator.model.AllowCustomRoutingTrafficRequest
  ): zio.aws.globalaccelerator.model.AllowCustomRoutingTrafficRequest.ReadOnly =
    new Wrapper(impl)
}
